@@ -2,10 +2,10 @@ package LWPx::UserAgent::Cached;
 
 # ABSTRACT: Subclass of LWP::UserAgent that caches HTTP GET requests
 
-use Modern::Perl '2011';    ## no critic (Modules::ProhibitUseQuotedVersion)
-
-our $VERSION = '0.007';     # VERSION
+use strict;
+use warnings;
 use utf8;
+our $VERSION = '0.008';
 
 ## no critic (Bangs::ProhibitCommentedOutCode)
 
@@ -24,11 +24,11 @@ use utf8;
 #pod =head1 DESCRIPTION
 #pod
 #pod This module borrows the caching logic from
-#pod L<WWW::Mechanize::Cached|WWW::Mechanize::Cached> but
+#pod L<C<WWW::Mechanize::Cached>|WWW::Mechanize::Cached> but
 #pod without inheriting from
-#pod L<WWW::Mechanize|WWW::Mechanize>; instead it is just
+#pod L<C<WWW::Mechanize>|WWW::Mechanize>; instead it is just
 #pod a direct subclass of
-#pod L<LWP::UserAgent|LWP::UserAgent>.
+#pod L<C<LWP::UserAgent>|LWP::UserAgent>.
 #pod
 #pod =head2 HTTP/1.1 cache operation
 #pod
@@ -41,11 +41,11 @@ use utf8;
 #pod
 #pod =over
 #pod
-#pod =item L<LWP::UserAgent|LWP::UserAgent>
+#pod =item L<C<LWP::UserAgent>|LWP::UserAgent>
 #pod
 #pod Parent of this class.
 #pod
-#pod =item L<WWW::Mechanize::Cached|WWW::Mechanize::Cached>
+#pod =item L<C<WWW::Mechanize::Cached>|WWW::Mechanize::Cached>
 #pod
 #pod Inspiration for this class.
 #pod
@@ -64,7 +64,7 @@ extends 'LWP::UserAgent';
 #pod =attr cache
 #pod
 #pod Settable at construction, defaults to using
-#pod L<CHI::Driver::RawMemory|CHI::Driver::RawMemory> with
+#pod L<C<CHI::Driver::RawMemory>|CHI::Driver::RawMemory> with
 #pod an instance-specific hash datastore and a namespace with the current
 #pod package name. You can use your own caching object here as long as it has
 #pod C<get> and C<set> methods.
@@ -216,10 +216,10 @@ sub _set_cache {
     my ( $response, $self ) = @_;
     return if not $response;
 
-    if (not(    $response->header('client-transfer-encoding')
-            and 'ARRAY' eq ref $response->header('client-transfer-encoding')
+    if (not($response->header('client-transfer-encoding')
             and any { 'chunked' eq $_ }
-            @{ $response->header('client-transfer-encoding') } )
+            $response->header('client-transfer-encoding')
+        )
         )
     {
         for ( $response->header('size') ) {
@@ -281,7 +281,7 @@ LWPx::UserAgent::Cached - Subclass of LWP::UserAgent that caches HTTP GET reques
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -298,11 +298,11 @@ version 0.007
 =head1 DESCRIPTION
 
 This module borrows the caching logic from
-L<WWW::Mechanize::Cached|WWW::Mechanize::Cached> but
+L<C<WWW::Mechanize::Cached>|WWW::Mechanize::Cached> but
 without inheriting from
-L<WWW::Mechanize|WWW::Mechanize>; instead it is just
+L<C<WWW::Mechanize>|WWW::Mechanize>; instead it is just
 a direct subclass of
-L<LWP::UserAgent|LWP::UserAgent>.
+L<C<LWP::UserAgent>|LWP::UserAgent>.
 
 =head2 HTTP/1.1 cache operation
 
@@ -316,7 +316,7 @@ response) and the C<Pragma: no-cache> request header.
 =head2 cache
 
 Settable at construction, defaults to using
-L<CHI::Driver::RawMemory|CHI::Driver::RawMemory> with
+L<C<CHI::Driver::RawMemory>|CHI::Driver::RawMemory> with
 an instance-specific hash datastore and a namespace with the current
 package name. You can use your own caching object here as long as it has
 C<get> and C<set> methods.
@@ -354,15 +354,31 @@ Settable at construction or anytime thereafter, indicates whether we should
 only cache positive responses (HTTP response codes from C<200> to C<300>
 inclusive) or cache everything. Defaults to true.
 
+=head1 REQUIRES
+
+=over 4
+
+=item * L<CHI|CHI>
+
+=item * L<HTTP::Status|HTTP::Status>
+
+=item * L<Moo|Moo>
+
+=item * L<Types::Standard|Types::Standard>
+
+=item * L<namespace::clean|namespace::clean>
+
+=back
+
 =head1 SEE ALSO
 
 =over
 
-=item L<LWP::UserAgent|LWP::UserAgent>
+=item L<C<LWP::UserAgent>|LWP::UserAgent>
 
 Parent of this class.
 
-=item L<WWW::Mechanize::Cached|WWW::Mechanize::Cached>
+=item L<C<WWW::Mechanize::Cached>|WWW::Mechanize::Cached>
 
 Inspiration for this class.
 
@@ -493,7 +509,7 @@ Mark Gardner <mjgardner@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by ZipRecruiter.
+This software is copyright (c) 2016 by ZipRecruiter.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
